AMPSAdCallBackChannelMethod class

开屏和插屏广告加载方法

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

onAdClicked → const String
onAdClosed → const String
onAdExposure → const String
onAdReward → const String
onAdShow → const String
onAdShowError → const String
onLoadFailure → const String
onLoadSuccess → const String
onRenderFailure → const String
onRenderOk → const String
onVideoPlayEnd → const String
onVideoPlayError → const String
onVideoPlayStart → const String
onVideoSkipToEnd → const String