AMPSChannels class
Flutter层的常量,此部分各端应该有一份完全一样的对应。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ampsSdk → const String
- ampsSdkInit → const String
- ampsSdkInterstitialAdLoad → const String
- ampsSdkNativeAdLoad → const String
- ampsSdkSplash → const String
- ampsSdkSplashAdLoad → const String