AMPSIInitCallBack class

  1. 定义回调接口(抽象类)

Constructors

AMPSIInitCallBack({InitSuccessCallBack? initSuccess, InitializingCallBack? initializing, AlreadyInitCallBack? alreadyInit, InitFailedCallBack? initFailed})

Properties

alreadyInit AlreadyInitCallBack?
已经初始化的回调
latefinal
hashCode int
The hash code for this object.
no setterinherited
initFailed InitFailedCallBack?
初始化失败的回调
latefinal
initializing AlreadyInitCallBack?
正在初始化的回调
latefinal
initSuccess AlreadyInitCallBack?
初始化成功的回调
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited