AMPSInterstitialAd class

插屏广告对象入口类

Constructors

AMPSInterstitialAd({required AdOptions config, AdCallBack? mCallBack})

Properties

config AdOptions
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mCallBack AdCallBack?
getter/setter pair
needLoad bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getECPM() Future<num>
获取ecpm
isReadyAd() Future<bool>
是否有预加载
load() → void
广告加载调用方法
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyRTBLoss(double winPrice, double secPrice, String lossReason, {String? winAdnId}) → dynamic
上报竞败
notifyRTBWin(double winPrice, double secPrice, {String? winAdnId}) → dynamic
上报竞胜
registerChannel(int id, AdWidgetNeedCloseCall? closeWidgetCall) → void
setMethodCallHandler(AdWidgetNeedCloseCall? closeWidgetCall) → void
showAd() → void
插屏广告显示调用方法
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited