ScreenMode enum

提供给Android使用 屏幕广告区域模式 (Splash Ad Display Mode) 用于定义开屏广告 View 的绘制边界和高度计算方式。

Inheritance
Available extensions

Values

fullScreen → const ScreenMode
  1. 全屏填充区域 (FULL_FILL): 广告占据整个屏幕的物理像素区域 (Real Screen Size)。 适用于隐藏所有系统栏的沉浸式体验。 计算高度:Real Screen Height
const ScreenMode(0)
statusBarVisible → const ScreenMode
  1. 顶部安全区域 (TOP_SAFE_REGION): 广告绘制区域在状态栏下方,但延伸至屏幕最底。 计算高度:Real Screen Height - Status Bar Height (MediaQueryData.padding.top)
const ScreenMode(1)
statusNavBarVisible → const ScreenMode
  1. 底部安全区域 (BOTTOM_SAFE_REGION): 广告绘制区域从屏幕最顶开始,截止到底部导航/手势区域上方。 计算高度:Real Screen Height - Navigation Bar Height (MediaQueryData.padding.bottom)
const ScreenMode(2)
statusNavAndBarVisible → const ScreenMode
  1. 全部安全区域 (ALL_SAFE_REGION): 广告绘制区域在状态栏下方,截止到导航栏上方。 这是最安全的模式,避开所有系统安全区域。 计算高度:Real Screen Height - Status Bar Height - Navigation Bar Height
const ScreenMode(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScreenMode>
A constant List of the values in this enum, in order of their declaration.