AMPSCustomControllerParam class
AMPSCustomController 的参数类
Constructors
- AMPSCustomControllerParam({bool? isCanUsePhoneState, String? OAID, bool? isSupportPersonalized, UnderageTag? getUnderageTag, String? userAgent, bool? isCanUseSensor, bool? isLocationEnabled, AMPSLocation? location})
Properties
- getUnderageTag → UnderageTag?
-
适龄标记
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCanUsePhoneState → bool?
-
是否可以使用PhoneState权限
final
- isCanUseSensor → bool?
-
是否可以使用传感器
final
- isLocationEnabled → bool?
-
是否允许SDK自身获取定位
final
- isSupportPersonalized → bool?
-
是否允许使用个性化推荐
final
- location → AMPSLocation?
-
三方设置的位置信息
final
- OAID → String?
-
透传OAID
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgent → String?
-
userAgent
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited