AMPSLocation class
记录三方传入的位置信息,用于上报
Constructors
- AMPSLocation({double? longitude, double? latitude, CoordinateType? coordinate, int? timeStamp})
- 构造函数,支持初始化时设置属性
Properties
- coordinate ↔ CoordinateType?
-
坐标系类型,对应原代码中的AMPSConstants.CoordinateType
(默认 0:GCJ02 1:WGS84 2:BAIDU,仅支持QM渠道)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude ↔ double?
-
纬度
getter/setter pair
- longitude ↔ double?
-
经度
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeStamp ↔ int?
-
时间戳
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - 转为 Map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited