AmpsNativeInteractiveListener class

Constructors

AmpsNativeInteractiveListener({AdEventCallback? onAdShow, AdEventCallback? onAdExposure, AdEventCallback? onAdClicked, AdEventCallback? toCloseAd})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onAdClicked AdEventCallback?
final
onAdExposure AdEventCallback?
final
onAdShow AdEventCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toCloseAd AdEventCallback?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited