AmpsVideoPlayListener class
Constructors
- AmpsVideoPlayListener({VideoPlayerEventCallback? onVideoInit, VideoPlayerEventCallback? onVideoLoading, VideoPlayerEventCallback? onVideoReady, VideoPlayerEventCallback? onVideoLoaded, VideoPlayerEventCallback? onVideoPlayStart, VideoPlayerEventCallback? onVideoPlayComplete, VideoPlayerEventCallback? onVideoPause, VideoPlayerEventCallback? onVideoResume, VideoPlayerEventCallback? onVideoStop, VideoPlayerEventCallback? onVideoClicked, VideoPlayerErrorCallback? onVideoPlayError})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onVideoClicked → AMPSNativeRenderCallback?
-
final
- onVideoInit → AMPSNativeRenderCallback?
-
final
- onVideoLoaded → AMPSNativeRenderCallback?
-
final
- onVideoLoading → AMPSNativeRenderCallback?
-
final
- onVideoPause → AMPSNativeRenderCallback?
-
final
- onVideoPlayComplete → AMPSNativeRenderCallback?
-
final
- onVideoPlayError → AMPSNativeRenderFailedCallback?
-
final
- onVideoPlayStart → AMPSNativeRenderCallback?
-
final
- onVideoReady → AMPSNativeRenderCallback?
-
final
- onVideoResume → AMPSNativeRenderCallback?
-
final
- onVideoStop → AMPSNativeRenderCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited