AMPSControllerKey class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- getUnderageTag → const String
- 对应 getUnderageTag 的序列化键
- isCanUsePhoneState → const String
- 对应 isCanUsePhoneState 的序列化键
- isCanUseSensor → const String
- 对应 isCanUseSensor 的序列化键
- isLocationEnabled → const String
- 对应 isLocationEnabled 的序列化键
- isSupportPersonalized → const String
- 对应 isSupportPersonalized 的序列化键
- location → const String
- 对应 location 的序列化键
- oaid → const String
- 对应 OAID 的序列化键
- userAgent → const String
- 对应 userAgent 的序列化键