AMPSInitConfigKey class

Constructors

AMPSInitConfigKey()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adapterNames → const String
对应 adapterNames 的序列化键
adapterStatusBarHeight → const String
对应 adapterStatusBarHeight 的序列化键
adController → const String
对应 adController 的序列化键
androidId → const String
appId → const String
对应 appId 的序列化键
appName → const String
对应 appName 的序列化键
city → const String
对应 city 的序列化键
countryCN → const String
对应 countryCN 的序列化键
currency → const String
对应 currency 的序列化键
customUA → const String
对应 customUA 的序列化键
extensionParam → const String
对应 extensionParam 的序列化键
gaId → const String
isDebugSetting → const String
对应 _isDebugSetting 的序列化键
isMediation → const String
对应 isMediation 的序列化键
isTestAd → const String
对应 isTestAd 的序列化键
isUseHttps → const String
对应 _isUseHttps 的序列化键
optionFields → const String
对应 optionFields 的序列化键
optionInfo → const String
province → const String
对应 province 的序列化键
region → const String
对应 region 的序列化键
testModel → const String
uiModel → const String
对应 uiModel 的序列化键
userId → const String
对应 userId 的序列化键