DownLoadWidget class

下载六要素,android独有

Inheritance

Constructors

DownLoadWidget({required double width, required double x, required double y, required double fontSize, required String fontColor, required String content, dynamic downloadListener})

Properties

content String
final
downloadListener → dynamic
final
fontColor String
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited