NativeUnifiedWidget class

自渲染组件自定义内容

Inheritance

Constructors

NativeUnifiedWidget({required double height, required String backgroundColor, required List<LayoutWidget> children})

Properties

backgroundColor → String
final
children → List<LayoutWidget>
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap({double? width}) → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited