UnifiedActionButtonWidget class

actionText

Inheritance

Constructors

UnifiedActionButtonWidget({required double fontSize, required String fontColor, required double x, required double y, double? height, double? width, String? backgroundColor, ButtonType buttonType = ButtonType.capsule, AMPSAdItemClickType clickType = AMPSAdItemClickType.none, AMPSAdItemClickIdType clickIdType = AMPSAdItemClickIdType.click})

Properties

backgroundColor ↔ String?
getter/setter pair
buttonType ↔ ButtonType
getter/setter pair
clickIdType ↔ AMPSAdItemClickIdType
getter/setter pair
clickType ↔ AMPSAdItemClickType
getter/setter pair
fontColor → String
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double?
getter/setter pair
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited