AMPSAdSdkMethodNames class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- init → const String
- 初始化AMPS广告SDK的方法名
- interstitialGetECPM → const String
- interstitialIsReadyAd → const String
- interstitialLoad → const String
- 插屏相关方法
- interstitialNotifyRTBLoss → const String
- interstitialNotifyRTBWin → const String
- interstitialShowAd → const String
- nativeGetECPM → const String
- nativeGetVideoDuration → const String
- nativeIsNativeExpress → const String
- nativeIsReadyAd → const String
- nativeLoad → const String
- 原生与自渲染相关方法
- nativeNotifyRTBLoss → const String
- nativeNotifyRTBWin → const String
- nativeSetVideoPlayConfig → const String
- nativeShowAd → const String
- splashGetECPM → const String
- splashIsReadyAd → const String
- splashLoad → const String
- 开屏相关方法
- splashNotifyRTBLoss → const String
- splashNotifyRTBWin → const String
- splashShowAd → const String