AMPSNativeCallBackChannelMethod class

原生和原生自渲染标识

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

loadFail → const String
loadOk → const String
onAdClicked → const String
onAdClosed → const String
onAdExposure → const String
onAdShow → const String
具体广告组件回调
onVideoClicked → const String
onVideoInit → const String
视频组件回调
onVideoLoaded → const String
onVideoLoading → const String
onVideoPause → const String
onVideoPlayComplete → const String
onVideoPlayError → const String
onVideoPlayStart → const String
onVideoReady → const String
onVideoResume → const String
onVideoStop → const String
renderFailed → const String
renderSuccess → const String