AMPSNativeAd class

原生广告类

Constructors

AMPSNativeAd({required AdOptions config, NativeType nativeType = NativeType.native, dynamic mCallBack, dynamic mRenderCallBack, dynamic mInteractiveCallBack, dynamic mVideoPlayerCallBack})

Properties

config AdOptions
默认原生模式【鸿蒙中原生和自渲染是一样的调用入口;Android是两个不同的入口,所以这里需要说明文档说明】
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mCallBack ↔ dynamic
getter/setter pair
mCloseWidgetCall AdWidgetNeedCloseCall?
getter/setter pair
mDownloadListener ↔ dynamic
getter/setter pair
mInteractiveCallBack ↔ dynamic
getter/setter pair
mRenderCallBack ↔ dynamic
getter/setter pair
mVideoPlayerCallBack ↔ dynamic
getter/setter pair
nativeType NativeType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getECPM(String adId) Future<num>
获取ecpm
getVideoDuration(String adId) Future<num>
获取视频播放时长
isNativeExpress(String adId) Future<bool>
获取是否是自渲染
isReadyAd(String adId) Future<bool>
获取是否有预加载
load() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyRTBLoss(double winPrice, double secPrice, String lossReason, String adId, {String? winAdnId}) → dynamic
上报竞败
notifyRTBWin(double winPrice, double secPrice, String adId, {String? winAdnId}) → dynamic
上报竞胜
setAdCloseCallBack(AdWidgetNeedCloseCall? closeWidgetCall) → void
setDownloadListener(dynamic downloadListener) → void
setVideoPlayConfig(AMPSAdVideoPlayConfig videoPlayConfig) → void
设置视频播放配置
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited