AdOptions class

广告加载入参参数

Constructors

AdOptions({required String spaceId, String? apiKey, int? adCount, String? s2sImpl, int? timeoutInterval, List<num?>? expressSize, int? splashAdBottomBuilderHeight, String? userId, String? extra, String? ipAddress, ScreenMode? screenMode})

Properties

adCount int?
final
apiKey String?
final
expressSize List<num?>?
final
extra String?
final
hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s2sImpl String?
final
screenMode ScreenMode?
final
spaceId String
final
splashAdBottomBuilderHeight int?
final
timeoutInterval int?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap({NativeType? nativeType}) Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited