AMPSCustomController class
用户控制类. 重写相关方法设置SDK可用内容
Constructors
- AMPSCustomController({required AMPSCustomControllerParam? param})
Properties
- getUnderageTag ↔ UnderageTag
-
适龄标记
取值参考 UnderageTag
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCanUsePhoneState ↔ bool
-
是否可以使用PhoneState权限
getter/setter pair
- isCanUseSensor ↔ bool
-
是否可以使用传感器
getter/setter pair
- isLocationEnabled ↔ bool
-
是否允许SDK自身获取定位
getter/setter pair
- isSupportPersonalized ↔ bool
-
是否允许使用个性化推荐
true: 允许 false: 不允许
getter/setter pair
- location ↔ AMPSLocation?
-
用于记录,三方设置的位置信息
getter/setter pair
- oaid ↔ String
-
透传OAID
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgent ↔ String?
-
userAgent
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - 转为 Map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited