AMPSInitConfig class
AMPSInitConfig类,用于表示初始化配置
Constructors
- AMPSInitConfig(AMPSBuilder builder)
- 构造函数,接收Builder对象并进行初始化
Properties
-
adapterNames
→ List<
String> ? -
聚合模式下,提前初始化的第三方广告渠道平台
final
- adapterStatusBarHeight → bool
-
final
- adController → AMPSCustomController
-
final
- androidID → String?
-
androidID
final
- appId ↔ String
-
媒体的账户ID
getter/setter pair
- appName → String
-
final
- city → String?
-
final
- countryCN → int
-
国家
final
- currency → String
-
添加支持的现金类型
final
- customUA → String?
-
自定义UA
final
-
extensionParam
→ Map<
String, Map< String, dynamic> > -
聚合模式下,传递第三方广告渠道平台初始化参数
final
- gaId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMediation → bool
-
final
- isTestAd → bool
-
是否测试广告位(是否计价)
final
-
optionFields
→ Map<
String, dynamic> -
final
- optionInfo → String?
-
optionInfo Android特有
final
- province → String?
-
final
- region → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uiModel → UiModel
-
final
- userId → String
-
final
Methods
-
a7bc8pp9i7d(
String a5) → void -
disableCrashCollect(
) → bool - 禁用奔溃日志收集,默认否【默认收集日志】
-
getAdapterNames(
) → List< String> ? -
getAppId(
) → String - 获取appId的方法
-
getAppName(
) → String - 获取appName的方法
-
getCity(
) → String? - 获取设置的城市
-
getCountryCN(
) → int - 获取countryCN的方法
-
getCurrency(
) → String - 获取currency的方法
-
getCustomOAID(
) → String - 获取自定义OAID的方法
-
getDarkColor(
) → String -
getExtensionParamItems(
String key) → Map< String, dynamic> - 获取设置的某个第三方平台参数
-
getExtensionParams(
) → Map< String, Map< String, dynamic> > - 获取设置的第三方平台参数
-
getIsTestAd(
) → bool - 获取isTestAd的方法
-
getLightColor(
) → String -
getOptionFields(
) → Map< String, dynamic> - 获取optionFields的方法
-
getProvince(
) → String? - 获取设置的省份
-
getRegion(
) → String? - 获取设置的地区
-
getUiModel(
) → UiModel - 获取uiModel的方法
-
getUserAgent(
) → String? - 获取用户设置的userAgent
-
getUserId(
) → String - 获取userId的方法
-
getUserLocation(
) → AMPSLocation? - 用于提供获取用户是否统一SDK自身定位。
-
isCanUsePhoneState(
) → bool - 获取是否可以使用电话状态的方法
-
isCanUseSensor(
) → bool - 获取是否可以使用传感器
-
isDebugSetting(
) → bool - 获取isDebugSetting的方法
-
isLocationEnabled(
) → bool - 用于提供获取用户是否统一SDK自身定位。
-
isUseHttps(
) → bool - 获取isUseHttps的方法
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
bool testModel) → Map< String, dynamic> - 转为 Map(用于JSON序列化)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isMediationStatic ↔ bool
-
getter/setter pair